package cn.com.qmth.scancloud.tools.config;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.boot.WebApplicationType;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;
import org.springframework.core.env.ConfigurableEnvironment;

public class ApplicationRunListener implements SpringApplicationRunListener, Ordered {

    private static final Logger log = LoggerFactory.getLogger(ApplicationRunListener.class);

    private final SpringApplication application;

    public ApplicationRunListener(SpringApplication application, String[] args) {
        this.application = application;
    }

    @Override
    public void started(ConfigurableApplicationContext context) {
        if (WebApplicationType.SERVLET != application.getWebApplicationType()) {
            return;
        }

        ConfigurableEnvironment environment = context.getEnvironment();
        log.info("started... {}", environment.getProperty("server.port"));

        // 任务配置 & 执行
        new TaskConfig().doTask();

        if (StringUtils.isNotEmpty(environment.getProperty("scan.tool.taskType"))
                && environment.getProperty("scan.tool.stop", Boolean.class, false)) {
            context.stop();
        }
    }

    @Override
    public int getOrder() {
        return LOWEST_PRECEDENCE;
    }

}
