package cn.com.qmth.scancloud.tools.service;

import cn.com.qmth.scancloud.tools.utils.StatusException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AbstractTask {

    private static final Logger log = LoggerFactory.getLogger(AbstractTask.class);

    public void run() {
        long start = System.currentTimeMillis();

        try {
            System.out.println();
            log.info("【{}】任务开始...", this.getTaskName());

            this.execute();
        } catch (StatusException e) {
            log.error("【{}】任务失败，原因：{}", this.getTaskName(), e.getMessage());
        } catch (Exception e) {
            log.error("【{}】任务异常！", this.getTaskName(), e);
        } finally {
            long cost = (System.currentTimeMillis() - start) / 1000;
            log.info("【{}】任务结束... 耗时：{}秒", this.getTaskName(), cost);
            System.exit(1);
        }
    }

    protected abstract String getTaskName();

    protected abstract void execute();

}
