package cn.com.qmth.scancloud.tools.service.impl;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import cn.com.qmth.scancloud.tools.config.SysProperty;
import cn.com.qmth.scancloud.tools.enums.RoleType;
import cn.com.qmth.scancloud.tools.enums.TaskType;
import cn.com.qmth.scancloud.tools.model.User;
import cn.com.qmth.scancloud.tools.service.AbstractTask;
import cn.com.qmth.scancloud.tools.utils.FileHelper;
import cn.com.qmth.scancloud.tools.utils.HttpHelper;
import cn.com.qmth.scancloud.tools.utils.JsonHelper;
import cn.com.qmth.scancloud.tools.utils.StatusException;

/**
 * 管理员用户导入
 */
public class UserImportTask extends AbstractTask {

    private static final Logger log = LoggerFactory.getLogger(UserImportTask.class);

    @Override
    protected String getTaskName() {
        return TaskType.USER_IMPORT.getTitle();
    }

    @Override
    protected void execute() {
        Long schoolId = SysProperty.SCHOOL_ID;
        if (schoolId == null) {
            throw new StatusException("【scan.tool.schoolId】未配置！");
        }
        if (!SysProperty.USER_IMPORT.endsWith(".txt")) {
            throw new StatusException("导入模板目前仅支持后缀名为“.txt”的文件！");
        }

        int total = 0;
        List<User> list = new ArrayList<>();
        File file = new File(SysProperty.DATA_DIR + "/" + SysProperty.USER_IMPORT);
        List<String> lines = FileHelper.readAllLines(file);
        for (int n = 1; n < lines.size(); n++) {

            User data = this.parseValues(total, lines.get(n), SysProperty.TEMPLATE_SEPARATOR);
            if (data != null) {
                data.setSchoolId(schoolId);
                list.add(data);
            }

            total++;
        }

        log.info("导入文件全部行数共 {} 行，实际有效数据共 {} 条！", total, list.size()-1);
        if (CollectionUtils.isEmpty(list)) {
            return;
        }

        String url = SysProperty.SCAN_SERVER_URL + "/api/tool/import/user";

        String json = JsonHelper.toJson(list);

        String result = HttpHelper.post(url, json);
        log.info("已处理数：{} 进度：100% {}", list.size(), result);
    }

    private User parseValues(int index, String line, String templateSeparator) {
        if (StringUtils.isBlank(line)) {
            return null;
        }

        line = StringUtils.deleteWhitespace(line);
        String[] values = StringUtils.splitByWholeSeparatorPreserveAllTokens(line, templateSeparator);

        try {
            String name = null;
            String loginName = null;
            String password = null;

            // 默认模板：姓名|账号|密码
            name = values[0];
            loginName = values[1];
            password = values[2];
            if (StringUtils.isEmpty(name)) {
                throw new StatusException(String.format("【第%s行】“姓名”字段不能为空！ %s", index + 1, line));
            }
            if (StringUtils.isEmpty(loginName)) {
                throw new StatusException(String.format("【第%s行】“账号”字段不能为空！ %s", index + 1, line));
            }
            if (StringUtils.isEmpty(password)) {
                throw new StatusException(String.format("【第%s行】“密码”字段不能为空！ %s", index + 1, line));
            }

            User data = new User();
            data.setName(name);
            data.setLoginName(loginName);
            data.setPassword(password);
            // 默认“学校管理员”
            data.setRole(RoleType.SCHOOL_ADMIN);
            return data;
        } catch (ArrayIndexOutOfBoundsException e) {
            log.error("【第{}行】内容格式错误！ {} {}", index + 1, line, e.toString());
            throw new StatusException("数据内容有误！");
        }
    }

}
