package cn.com.qmth.scancloud.tools.utils;

import com.google.common.io.Files;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.LineIterator;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.List;

public class FileHelper {

    private static final Logger log = LoggerFactory.getLogger(FileHelper.class);

    /**
     * 获取文件后缀名，包括"."
     */
    public static String getFileSuffix(String fileName) {
        if (StringUtils.isNotEmpty(fileName)) {
            int index = fileName.lastIndexOf(".");
            if (index > 0) {
                return fileName.substring(index).toLowerCase();
            }
        }

        return "";
    }

    /**
     * 创建文件目录
     */
    public static void makeDirs(String dirPath) {
        if (StringUtils.isBlank(dirPath)) {
            return;
        }
        File dir = new File(dirPath);
        if (!dir.exists()) {
            dir.mkdirs();
        }
    }

    /**
     * 读取文件内容（一次性读取）
     */
    public static List<String> readAllLines(File file) {
        try {
            return Files.readLines(file, StandardCharsets.UTF_8);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new StatusException("读取文件失败！ " + e.getMessage());
        }
    }

    /**
     * 读取文件内容（迭代按行读取）
     */
    public static LineIterator readLines(File file) throws IOException {
        return FileUtils.lineIterator(file, StandardCharsets.UTF_8.name());
    }

    /**
     * 写入文件内容
     */
    public static void writeLines(File file, List<String> lines) {
        writeLines(file, lines, false);
    }

    /**
     * 写入文件内容（支持追加）
     */
    public static void writeLines(File file, List<String> lines, boolean append) {
        if (!file.exists()) {
            makeDirs(file.getParent());
        }

        try {
            if (lines == null) {
                lines = new ArrayList<>();
            }
            FileUtils.writeLines(file, StandardCharsets.UTF_8.name(), lines, append);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new StatusException("写入文件失败！ " + e.getMessage());
        }
    }

}
